@@ -5,9 +5,9 @@
  *
  * Displays all optinos about display preferences
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display.php 13103 2008-05-07 16:28:41Z pdontthink $
+ * @version $Id: display.php 13916 2010-02-16 20:20:57Z pdontthink $
  * @package squirrelmail
  */
 
@@ -330,6 +330,13 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'strip_sigs',
+        'caption' => _("Strip signature when replying"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'body_quote',
         'caption' => _("Prefix for Original Message when Replying"),
