@@ -5,9 +5,9 @@
  *
  * Setup of the mailfetch plugin.
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options.php 13546 2009-04-15 18:22:55Z jervfors $
+ * @version $Id: options.php 13951 2010-06-21 07:19:31Z pdontthink $
  * @package plugins
  * @subpackage mail_fetch
  */
@@ -55,6 +55,8 @@ sqgetGlobalVar('mf_login',         $mf_login,         SQ_POST);
 sqgetGlobalVar('mf_fref',          $mf_fref,          SQ_POST);
 sqgetGlobalVar('mf_lmos',          $mf_lmos,          SQ_POST);
 sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
+$mf_port = trim($mf_port);
+$mf_server = trim($mf_server);
 
 
 /* end globals */
@@ -63,6 +65,19 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
 
     switch( $mf_action ) {
     case 'add':
+
+        $mf_action = 'config';
+
+        // restrict port number if necessary
+        //
+        $message = validate_mail_fetch_port_number($mf_port);
+        if (!empty($message)) break;
+
+        // restrict server address if necessary
+        //
+        $message = validate_mail_fetch_server_address($mf_server);
+        if (!empty($message)) break;
+
         if ($mf_sn<1) $mf_sn=0;
         if (!isset($mf_server)) return;
         setPref($data_dir,$username,"mailfetch_server_$mf_sn", (isset($mf_server)?$mf_server:""));
@@ -85,10 +100,28 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
         setPref($data_dir,$username,"mailfetch_subfolder_$mf_sn",(isset($mf_subfolder)?$mf_subfolder:""));
         $mf_sn++;
         setPref($data_dir,$username,'mailfetch_server_number', $mf_sn);
-        $mf_action = 'config';
         break;
+
+    // modify a server
+    //
     case 'confirm_modify':
-        //modify    a server
+
+        // restrict port number if necessary
+        //
+        $message = validate_mail_fetch_port_number($mf_port);
+        if (!empty($message)) {
+            $mf_action = 'Modify';
+            break;
+        }
+
+        // restrict server address if necessary
+        //
+        $message = validate_mail_fetch_server_address($mf_server);
+        if (!empty($message)) {
+            $mf_action = 'Modify';
+            break;
+        }
+
         if (!isset($mf_server)) return;
         setPref($data_dir,$username,"mailfetch_server_$mf_sn", (isset($mf_server)?$mf_server:""));
         setPref($data_dir,$username,"mailfetch_port_$mf_sn", (isset($mf_port)?$mf_port:110));
@@ -199,6 +232,14 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
                 ) ,
             'center', '', 'width="95%"' );
 
+    // display error or other messages if necessary
+    //
+    if (!empty($message)) {
+        echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="5" cellspacing="1"' ) .
+             html_tag( 'tr',
+             html_tag( 'td', '<b>' . $message . '</b>', 'center', $color[2] ));
+    }
+
     switch( $mf_action ) {
     case 'config':
         echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="5" cellspacing="1"' ) .
