@@ -3,12 +3,12 @@
 /**
  * setup.php -- Sent Subfolders Setup File
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
+ * Copyright (c) 1999-2010 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * $Id: setup.php 13271 2008-09-09 05:54:27Z pdontthink $
+ * $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package plugins
  * @subpackage sent_subfolders
  */
@@ -63,7 +63,6 @@ function sent_subfolders_check_handleAsSent() {
     global $handleAsSent_result, $sent_subfolders_base,
            $use_sent_subfolders;
 
-    $sent_subfolders_base = 'INBOX.Sent';
     $args = func_get_arg(0);
     sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
@@ -86,7 +85,7 @@ function sent_subfolders_check_handleAsSent() {
  * Loads sent_subfolders settings
  */
 function sent_subfolders_load_prefs() {
-    global $use_sent_subfolders, $data_dir, $username,
+    global $use_sent_subfolders, $data_dir, $username, $sent_folder,
            $sent_subfolders_setting, $sent_subfolders_base;
 
     $use_sent_subfolders = getPref
@@ -96,7 +95,7 @@ function sent_subfolders_load_prefs() {
     ($data_dir, $username, 'sent_subfolders_setting', SMPREF_SENT_SUBFOLDERS_DISABLED);
 
     $sent_subfolders_base = getPref
-    ($data_dir, $username, 'sent_subfolders_base', SMPREF_NONE);
+    ($data_dir, $username, 'sent_subfolders_base', $sent_folder);
 }
 
 /**
@@ -138,7 +137,8 @@ function sent_subfolders_optpage_loadhook_folders() {
         'caption' => _("Base Sent Folder"),
         'type'    => SMOPT_TYPE_FLDRLIST,
         'refresh' => SMOPT_REFRESH_FOLDERLIST,
-        'posvals' => $sent_subfolders_base_values
+        'posvals' => $sent_subfolders_base_values,
+        'save'    => 'save_option_sent_subfolders_base',
     );
 
     /* Add our option data to the global array. */
@@ -162,11 +162,13 @@ function filter_folders($fldr) {
  * Saves sent_subfolder_options
  */
 function save_option_sent_subfolders_setting($option) {
-    global $data_dir, $username, $use_sent_subfolders;
+    global $data_dir, $username, $use_sent_subfolders, $sent_subfolders_base;
 
     /* Set use_sent_subfolders as either on or off. */
     if ($option->new_value == SMPREF_SENT_SUBFOLDERS_DISABLED) {
         setPref($data_dir, $username, 'use_sent_subfolders', SMPREF_OFF);
+        // for lack of anything better
+        setPref($data_dir, $username, 'sent_folder', $sent_subfolders_base);
     } else {
         setPref($data_dir, $username, 'use_sent_subfolders', SMPREF_ON);
         setPref($data_dir, $username, 'move_to_sent', SMPREF_ON);
@@ -255,11 +257,14 @@ function sent_subfolders_update_sentfolder() {
                 $ic = sqimap_login
                 ($username, $key, $imapServerAddress, $imapPort, 10);
 
-                /* Auto-create the year folder, if it does not yet exist. */
-                if (!sqimap_mailbox_exists($ic, $year_folder)) {
-                    sqimap_mailbox_create($ic, $year_folder, ($level==1)?'':'noselect');
-                } else if (!sqimap_mailbox_is_subscribed($ic, $year_folder)) {
-                    sqimap_subscribe($ic, $year_folder);
+                /* Auto-create the year folder, if it does not yet exist.
+                   (only for monthly/quarterly modes */
+                if ($sent_subfolders_setting != SMPREF_SENT_SUBFOLDERS_YEARLY) {
+                    if (!sqimap_mailbox_exists($ic, $year_folder)) {
+                        sqimap_mailbox_create($ic, $year_folder, ($level==1)?'':'noselect');
+                    } else if (!sqimap_mailbox_is_subscribed($ic, $year_folder)) {
+                        sqimap_subscribe($ic, $year_folder);
+                    }
                 }
 
                 /* Auto-create the subfolder, if it does not yet exist. */
@@ -276,6 +281,17 @@ function sent_subfolders_update_sentfolder() {
     }
 }
 
+/**
+ * Update the folder settings/auto-create new subfolder
+ */
+function save_option_sent_subfolders_base($option) {
+    // first save the option as normal
+    save_option($option);
+
+    // now update folder settings and auto-create first subfolder if needed
+    sent_subfolders_update_sentfolder();
+}
+
 /**
  * Sets quarter subfolder names
  *
@@ -319,7 +335,7 @@ function sent_subfolder_getQuarter($month) {
  * @return boolean 1 - is part of sent_subfolders, 0 - is not part of sent_subfolders
  */
 function sent_subfolders_special_mailbox($mb) {
-    global $data_dir, $username;
+    global $data_dir, $username, $sent_folder;
 
     sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 /*
@@ -333,7 +349,7 @@ function sent_subfolders_special_mailbox($mb) {
 
     $use_sent_subfolders = getPref
         ($data_dir, $username, 'use_sent_subfolders', SMPREF_OFF);
-    $sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', 'na');
+    $sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', $sent_folder);
 
     if ($use_sent_subfolders == SMPREF_ON && 
     ($mb == $sent_subfolders_base || stristr($mb,$sent_subfolders_base. $cnd_delimiter) ) ) {
