@@ -5,7 +5,7 @@
  *
  * @copyright 2003-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: configtest.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: configtest.php 13933 2010-04-16 05:24:43Z pdontthink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -88,6 +88,32 @@ if(!check_php_version(4,1,0)) {
 
 echo $IND . 'PHP version ' . PHP_VERSION . " OK.<br />\n";
 
+// try to determine information about the user and group the web server is running as
+//
+$webOwnerID = 'N/A';
+$webOwnerInfo = array('name' => 'N/A');
+if (function_exists('posix_getuid'))
+    $webOwnerID = posix_getuid();
+if ($webOwnerID === FALSE)
+    $webOwnerID = 'N/A';
+if ($webOwnerID !== 'N/A' && function_exists('posix_getpwuid'))
+    $webOwnerInfo = posix_getpwuid($webOwnerID);
+if (!$webOwnerInfo)
+    $webOwnerInfo = array('name' => 'N/A');
+$webGroupID = 'N/A';
+$webGroupInfo = array('name' => 'N/A');
+if (function_exists('posix_getgid'))
+    $webGroupID = posix_getgid();
+if ($webGroupID === FALSE)
+    $webGroupID = 'N/A';
+if ($webGroupID !== 'N/A' && function_exists('posix_getgrgid'))
+    $webGroupInfo = posix_getgrgid($webGroupID);
+if (!$webGroupInfo)
+    $webGroupInfo = array('name' => 'N/A');
+
+echo $IND . 'Running as ' . $webOwnerInfo['name'] . '(' . $webOwnerID
+          . ') / ' . $webGroupInfo['name'] . '(' . $webGroupID . ")<br />\n";
+
 echo $IND . 'display_errors: ' . ini_get('display_errors') . "<br />\n";
 
 echo $IND . 'error_reporting: ' . ini_get('error_reporting') . "<br />\n";
