@@ -6,9 +6,9 @@
  * Creates folders on the IMAP server.
  * Called from folders.php
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_create.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: folders_create.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -37,8 +37,14 @@ sqgetGlobalVar('subfolder',    $subfolder,     SQ_POST);
 if (! sqgetGlobalVar('contain_subs', $contain_subs,  SQ_POST)) {
     unset($contain_subs);
 }
+if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
+    $submitted_token = '';
+}
 /* end of get globals */
 
+// first, validate security token
+sm_validate_security_token($submitted_token, 3600, TRUE);
+
 $folder_name = trim($folder_name);
 
 if (substr_count($folder_name, '"') || substr_count($folder_name, "\\") ||
