@@ -8,7 +8,7 @@
  *
  * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: left_main.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: left_main.php 13946 2010-06-21 00:43:54Z pdontthink $
  * @package squirrelmail
  */
 
@@ -302,6 +302,11 @@ sqgetGlobalVar('auto_create_done',$auto_create_done,SQ_SESSION);
 
 /* end globals */
 
+// Disable browser caching //
+header('Cache-Control: no-cache, no-store, must-revalidate');
+header('Pragma: no-cache');
+header('Expires: Sat, 1 Jan 2000 00:00:00 GMT');
+
 // open a connection on the imap port (143)
 $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 10); // the 10 is to hide the output
 
@@ -310,9 +315,7 @@ $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 1
  */
 if (isset($left_refresh) && ($left_refresh != '') &&
     !stristr($left_refresh, 'none')){
-    $xtra =  "\n<meta http-equiv=\"Expires\" content=\"Thu, 01 Dec 1994 16:00:00 GMT\">\n" .
-             "<meta http-equiv=\"Pragma\" content=\"no-cache\">\n".
-             "<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\">\n";
+    $xtra =  "\n<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\">\n";
 } else {
     $xtra = '';
 }
