@@ -6,12 +6,15 @@
  * top frame of printer_friendly_main.php
  * displays some javascript buttons for printing & closing
  *
- * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: printer_friendly_top.php,v 1.14.2.7 2006/04/14 22:27:08 jervfors Exp $
+ * @version $Id: printer_friendly_top.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
+/** This is the printer_friendly_top page */
+define('PAGE_NAME', 'printer_friendly_top');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
