@@ -7,7 +7,7 @@
  *
  * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: search.php 13905 2010-02-13 22:49:58Z pdontthink $
+ * @version $Id: search.php 13969 2010-07-21 19:21:39Z pdontthink $
  * @package squirrelmail
  * @subpackage search
  */
@@ -53,7 +53,10 @@ if (!sqgetGlobalVar('what',$what,SQ_GET)) {
 if (! sqgetGlobalVar('where',$where,SQ_GET) ||
     ! in_array( $where, array('BODY','TEXT','SUBJECT','FROM','CC','TO'))) {
     // make sure that 'where' is one if standard IMAP SEARCH keywords
-    $where = 'FROM';
+    if (isset($mailbox) && isSentMailbox($mailbox, TRUE))
+        $where = 'TO';
+    else
+        $where = 'FROM';
 }
 if ( !sqgetGlobalVar('preselected', $preselected, SQ_GET) || !is_array($preselected)) {
   $preselected = array();
