@@ -7,9 +7,9 @@
  * A SINGLE FREAKING COMMENT IN! Whoever is responsible for this,
  * be very ashamed.
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: view_text.php 12370 2007-05-09 13:46:30Z kink $
+ * @version $Id: view_text.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -31,7 +31,7 @@ sqgetGlobalVar('username',   $username,     SQ_SESSION);
 sqgetGlobalVar('onetimepad', $onetimepad,   SQ_SESSION);
 sqgetGlobalVar('delimiter',  $delimiter,    SQ_SESSION);
 sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
-sqgetGlobalVar('messages', $messages);
+sqgetGlobalVar('messages', $messages,       SQ_SESSION);
 sqgetGlobalVar('passed_id', $passed_id, SQ_GET);
 
 if ( sqgetGlobalVar('mailbox', $temp, SQ_GET) ) {
